==> nautobot-1.0.0a2.tar.gz: nautobot-1.0.0a2/README.md <==
![Nautobot](nautobot/docs/nautobot_logo.svg "Nautobot logo")

Nautobot is a Network Source of Truth and Network Automation Platform.  

> Nautobot was initially developed as a fork of NetBox (v2.10.4).  NetBox was originally developed by Jeremy Stretch at Digital Ocean and the NetBox Community.

Python framework with a [PostgreSQL](https://www.postgresql.org/) database. 

The complete documentation for Nautobot can be found at [Read the Docs](https://nautobot.readthedocs.io/en/stable/).

Questions? Comments? Start by perusing our [GitHub discussions](https://github.com/nautobot/nautobot/discussions) for the topic you have in mind,
or join us in the **#nautobot** Slack channel on [Network to Code](https://networktocode.slack.com)!

### Build Status

|             | status |
|-------------|------------|
| **main** | [![Build Status](https://travis-ci.com/nautobot/nautobot.svg?branch=main)](https://travis-ci.com/nautobot/nautobot) |
| **develop** | [![Build Status](https://travis-ci.com/nautobot/nautobot.svg?branch=develop)](https://travis-ci.com/nautobot/nautobot) |

### Screenshots

![Screenshot of main page](nautobot/docs/media/screenshot1.png "Main page")

---

![Screenshot of rack elevation](nautobot/docs/media/screenshot2.png "Rack elevation")

---

![Screenshot of prefix hierarchy](nautobot/docs/media/screenshot3.png "Prefix hierarchy")

## Installation

Please see [the documentation](https://nautobot.readthedocs.io/en/stable/) for
instructions on installing Nautobot.

## Providing Feedback

The best platform for general feedback, assistance, and other discussion is our
[GitHub discussions](https://github.com/nautobot/nautobot/discussions).
To report a bug or request a specific feature, please open a GitHub issue using
the [appropriate template](https://github.com/nautobot/nautobot/issues/new/choose).

If you are interested in contributing to the development of Nautobot, please read
our [contributing guide](CONTRIBUTING.md) prior to beginning any work.

## Related projects

Please see [our wiki](https://github.com/nautobot/nautobot/wiki/Related-Projects)
for a list of relevant community projects.

==> nautobot-1.0.3.tar.gz: nautobot-1.0.3/README.md <==
![Nautobot](https://raw.githubusercontent.com/nautobot/nautobot/develop/nautobot/docs/nautobot_logo.svg "Nautobot logo")

Nautobot is a Network Source of Truth and Network Automation Platform.  

> Nautobot was initially developed as a fork of NetBox (v2.10.4).  NetBox was originally developed by Jeremy Stretch at DigitalOcean and the NetBox Community.

Nautobot runs as a web application atop the [Django](https://www.djangoproject.com/)
Python framework with a [PostgreSQL](https://www.postgresql.org/) database. 

The complete documentation for Nautobot can be found at [Read the Docs](https://nautobot.readthedocs.io/en/stable/).

Questions? Comments? Start by perusing our [GitHub discussions](https://github.com/nautobot/nautobot/discussions) for the topic you have in mind,
or join us in the **#nautobot** Slack channel on [Network to Code](https://networktocode.slack.com)!

### Build Status

| Branch      | Status |
|-------------|------------|
| **main** | [![Build Status](https://travis-ci.com/nautobot/nautobot.svg?branch=main)](https://travis-ci.com/nautobot/nautobot) |
| **develop** | [![Build Status](https://travis-ci.com/nautobot/nautobot.svg?branch=develop)](https://travis-ci.com/nautobot/nautobot) |

### Screenshots

![Screenshot of main page](https://raw.githubusercontent.com/nautobot/nautobot/develop/nautobot/docs/media/screenshot1.png "Main page")

---

![Screenshot of rack elevation](https://raw.githubusercontent.com/nautobot/nautobot/develop/nautobot/docs/media/screenshot2.png "Rack elevation")

---

![Screenshot of prefix hierarchy](https://raw.githubusercontent.com/nautobot/nautobot/develop/nautobot/docs/media/screenshot3.png "Prefix hierarchy")

## Installation

Please see [the documentation](https://nautobot.readthedocs.io/en/stable/installation/) for instructions on installing Nautobot.

## Providing Feedback

The best platform for general feedback, assistance, and other discussion is our
[GitHub discussions](https://github.com/nautobot/nautobot/discussions).
To report a bug or request a specific feature, please open a GitHub issue using
the [appropriate template](https://github.com/nautobot/nautobot/issues/new/choose).

If you are interested in contributing to the development of Nautobot, please read
our [contributing guide](CONTRIBUTING.md) prior to beginning any work.

## Related projects

Please see [our wiki](https://github.com/nautobot/nautobot/wiki/Related-Projects)
for a list of relevant community projects.
